import React, { Component } from 'react'
import { is, fromJS } from 'immutable'
import { DatePicker } from 'antd'
import moment from 'moment'

const { MonthPicker } = DatePicker

/**
 * @description 自定义时间选择器
 */
class MkDatePicker extends Component {
  constructor(props) {
    super(props)

    const config = props.config

    let mode = 'date'
    let format = 'YYYY-MM-DD'

    if (config.type === 'datemonth') {
      mode = 'month'
      format = 'YYYY-MM'
    } else if (config.type === 'datetime') {
      mode = 'datetime'
      format = 'YYYY-MM-DD HH:mm:ss'
    }
    let value = config.initval || null
    if (value) {
      value = moment(value, format)
    }

    this.state = {
      value,
      mode,
      format
    }
  }

  shouldComponentUpdate (nextProps, nextState) {
    return !is(fromJS(this.state), fromJS(nextState))
  }

  componentWillUnmount () {
    this.setState = () => {
      return
    }
  }

  onChange = (val) => {
    const { format } = this.state

    this.props.onChange(val ? moment(val).format(format) : '')
  }

  render() {
    const { config } = this.props
    const { value, mode } = this.state

    if (mode === 'date') {
      return <DatePicker defaultValue={value} disabled={config.readonly} onChange={this.onChange}/>
    } else if (mode === 'month') {
      return <MonthPicker defaultValue={value} disabled={config.readonly} onChange={this.onChange}/>
    } else if (mode === 'datetime') {
      return <DatePicker defaultValue={value} showTime disabled={config.readonly} onChange={this.onChange}/>
    }
  }
}

export default MkDatePicker